@@ -126,15 +126,15 @@ impl Beacon {
 		// Case: == 0 results
 		if !response_json
 			.as_object()
-			.unwrap()
+			.expect("JSON is not an object")
 			.get("responseSummary")
-			.unwrap()
+			.expect("No 'responseSummary' property was found")
 			.as_object()
-			.unwrap()
+			.expect("'responseSummary' is not an object")
 			.get("exists")
-			.unwrap()
+			.expect("No 'exists' property found")
 			.as_bool()
-			.unwrap()
+			.expect("'exists' property is not a bool")
 		{
 			return EndpointReport::new().ok(None);
 		}
@@ -143,23 +143,30 @@ impl Beacon {
 		log::info!("Verifying results...");
 		response_json
 			.as_object()
-			.unwrap()
+			.expect("JSON is not an object")
 			.get("response")
-			.unwrap()
+			.expect("No 'response' property was found")
 			.as_object()
-			.unwrap()
+			.expect("'response' is not an object")
 			.get("resultSets")
-			.unwrap()
-			.as_object()
-			.unwrap()
-			.get("results")
-			.unwrap()
+			.expect("No 'resultSets' property was found")
 			.as_array()
-			.unwrap()
+			.expect("'resultSets' property is not an array")
 			.iter()
-			.map(|instance| match self.valid_schema(&schema, &instance.clone()) {
-				Ok(output) => EndpointReport::new().ok(Some(output)),
-				Err(e) => EndpointReport::new().error(e),
+			.map(|rs| {
+				rs
+				.as_object()
+				.expect("resultSet inside 'resultSets' property is not an object")
+				.get("results")
+				.expect("No 'results' property was found")
+				.as_array()
+				.expect("'results' property is not an array")
+				.iter()
+				.map(|instance| match self.valid_schema(&schema, &instance.clone()) {
+					Ok(output) => EndpointReport::new().ok(Some(output)),
+					Err(e) => EndpointReport::new().error(e),
+				})
+				.fold(EndpointReport::new().ok(None), EndpointReport::join)
 			})
 			.fold(EndpointReport::new().ok(None), EndpointReport::join)
 	}
